package de.theserverside.designpatterns.singleton;

/**
 * Implementierung des Singleton-Patterns mit synchronisiertem
 * Zugriff auf die Instanziierung und einfacher Bedingungsprfung
 */
public class CheckedLockingSingleton {
	private static CheckedLockingSingleton instance = null;

	/**
	 * Default-Konstruktor, der nicht auerhalb dieser Klasse
	 * aufgerufen werden kann
	 */
	private CheckedLockingSingleton() {}

	/**
	 * Statische Methode, liefert die einzige Instanz dieser
	 * Klasse zurck
	 */
	public static CheckedLockingSingleton getInstance() {
		if (instance == null) {
			synchronized(CheckedLockingSingleton.class) {
				instance = new CheckedLockingSingleton();
			}
		}
		return instance;
	}
}