package de.theserverside.designpatterns.singleton;

/**
 * Implementierung des Singleton-Patterns mit synchronisiertem
 * Zugriff auf die Instanziierung und zweifacher Bedingungsprfung
 */
public class DoubleCheckedLockingSingleton {
	private static DoubleCheckedLockingSingleton instance = null;

	/**
	 * Default-Konstruktor, der nicht auerhalb dieser Klasse
	 * aufgerufen werden kann
	 */
	private DoubleCheckedLockingSingleton() {}

	/**
	 * Statische Methode, liefert die einzige Instanz dieser
	 * Klasse zurck
	 */
	public static DoubleCheckedLockingSingleton getInstance() {
		if (instance == null) {
			synchronized(DoubleCheckedLockingSingleton.class) {
				if (instance == null) {
					instance = new DoubleCheckedLockingSingleton();
				}
			}
		}
		return instance;
	}
}